using System; 

namespace dinoch.demo
{ 

  public class DotNetMqHello
  { 
  private MQAX200.IMQQueueManager200  MyMqManager; 
  private MQAX200.IMQSession200       MyMqSession; 
  private MQAX200.IMQQueue200         MyMqQueue; 

  public DotNetMqHello()
    { 
      MyMqSession = new MQAX200.MQSessionClass();
      MyMqSession.ExceptionThreshold = 3; 
    } 

  public static void Main() 
    { 
      DotNetMqHello Hello= new DotNetMqHello();
      Hello.DoIt();
    } 

  private void DoIt() { 
    DoConnect();
    DoPut();
    DoGet();
    }

  private void DoConnect() {
    int OpenOptions; 
    String qmName= ""; // use the default local Queue Mgr
    Object obj = MyMqSession.AccessQueueManager(qmName);

    if (!(obj is MQAX200.IMQQueueManager200) )
	Console.WriteLine("Sorry! Could Not get a Queue Manager.");

    else {
	Console.WriteLine("Yes! Got a Queue Manager.");
	MyMqManager = (MQAX200.IMQQueueManager200) obj;
	if (MyMqManager != null) {
	    if(MyMqManager.IsConnected) { 
		OpenOptions = (int) MQAX200.MQ.MQOO_INPUT_AS_Q_DEF + (int) MQAX200.MQ.MQOO_OUTPUT; 
		MyMqQueue = (MQAX200.IMQQueue200) MyMqManager.AccessQueue("postcard", OpenOptions,"","",""); 
		if(MyMqQueue.IsOpen) 
		  Console.WriteLine("Connected to " + MyMqManager.name + "." + MyMqQueue.name ) ; 
	      } 
	  }
      }
  }

  private void DoPut() {
    MQAX200.IMQMessage200 Message; 
    MQAX200.IMQPutMessageOptions200 MessageOptions; 

    Message = (MQAX200.IMQMessage200) MyMqSession.AccessMessage(); 
    Message.WriteString(System.DateTime.Now.ToString() + ": This is the test message" ); 

    MessageOptions = (MQAX200.IMQPutMessageOptions200) MyMqSession.AccessPutMessageOptions(); 

    MyMqQueue.ClearErrorCodes();
    MyMqQueue.Put(Message, MessageOptions); 

    if(MyMqQueue.CompletionCode == 0) 
	Console.WriteLine("Put Succeeded.");

    else if(MyMqQueue.CompletionCode == 2) 
	Console.WriteLine("Put Failed (" + MyMqQueue.ReasonName + ")"); 
  }

  private void DoGet() {
    MQAX200.IMQMessage200 Message; 
    MQAX200.IMQGetMessageOptions200 MessageOptions; 

    Message = (MQAX200.IMQMessage200) MyMqSession.AccessMessage(); 
    MessageOptions = (MQAX200.IMQGetMessageOptions200) MyMqSession.AccessGetMessageOptions(); 

    if(MyMqQueue.IsOpen) { 
      MyMqQueue.ClearErrorCodes();
      // need to specify Missing.Value here because of an issue with the optional 3rd param (length)
      MyMqQueue.Get(Message,MessageOptions, System.Reflection.Missing.Value);

      if(MyMqQueue.CompletionCode == 0) {
	Console.WriteLine("Get Succeeded.");
	Console.WriteLine(Message.ReadString(Message.MessageLength));
      }

      else if(MyMqQueue.CompletionCode == 2) 
	Console.WriteLine("Get Failed (" + MyMqQueue.ReasonName + ")"); 
    } 
  }

  } // end class 

} // end namespace
